@@ -6,16 +6,18 @@ class Output:
     """
     Class to hold output data
 
-    **Atributes**:\n
+    During Simulation these are numpy arrays and are converted to pandas dataframes
+    at the end of the simulation
 
-    `water_storage` : `numpy` : Water storage in soil. TODO: it is numpy or pandas?
+    Atributes:
+    
+        water_flux (pandas.DataFrame, numpy.array): Daily water flux changes
 
-    TODO: water_flux and crop_growth are numpy arrays during simulation. I think it should be clearer
-    `water_flux` : `pandas.DataFrame` : Water flux
+        water_storage (pandas.DataFrame, numpy array): daily water content of each soil compartment
 
-    `crop_growth` : `pandas.DataFrame` : crop growth
+        crop_growth (pandas.DataFrame, numpy array): daily crop growth variables
 
-    `final_stats` : `pandas.DataFrame` : final stats
+        final_stats (pandas.DataFrame, numpy array): final stats at end of each season
 
     """
 
